==> hledger-web-1.14.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.14.1
id: hledger-web-1.14.1-5SXHQ6zrOO11sRiTgjYWCK
key: hledger-web-1.14.1-5SXHQ6zrOO11sRiTgjYWCK
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 63c8037e6f3be2bb96434fab1270dae6
exposed: True
exposed-modules:
    Hledger.Web Hledger.Web.Application Hledger.Web.Foundation
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Json Hledger.Web.Main
    Hledger.Web.Settings Hledger.Web.Settings.StaticFiles
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.14.1-5SXHQ6zrOO11sRiTgjYWCK
depends:
    Decimal-0.5.1-HbE7jjGKIya5lM4gHWrRW6
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    clientsession-0.9.1.2-38NHrIsylOx2AXJejwSg9m
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-1rtgJXlCmiO4uvSrqLTkUm
    conduit-extra-1.3.1.1-8uskN5QWhT7JNnQnEclXyj containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    filepath-1.4.2.1 hjsmin-0.2.0.2-EavLvoT0jfd25LMHcIIpPL
    hledger-1.14.2-6ijyllT42sLs8Q4ZumYed
    hledger-lib-1.14.1-9NYHb0J1gl72zhZXRAsXRz
    http-client-0.6.2-FYzm0eoFnV2JqsXDvGiJPm
    http-conduit-2.3.6.1-5UNQRe8NH3gK31dWzVQhJF
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE
    json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    megaparsec-7.0.4-1MZB8g6cytp9p69U9RRMNX mtl-2.2.2
    shakespeare-2.0.20-8evSeazN7uT8J74cUVd2ht template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    wai-3.2.2-6o6QSnPVpAu2Kn1dd7YFx6
    wai-extra-3.0.25-So7h98Ucog3drfRgIHkZr
    wai-handler-launch-3.0.2.4-EJZ7PNEYwM7L5dqtKhWdn7
    warp-3.2.26-ARWQwNlIIKp2SxhAdadjzn
    yaml-0.11.0.0-55g2vspuim9B5arWU8f1cj
    yesod-1.6.0-AluXMid29ui7tzGunz0JRK
    yesod-core-1.6.13-5AAJ7pvC5CvHtBUVbjAFSz
    yesod-form-1.6.4-DvLWkppIQfp27zzCO0YG50
    yesod-static-1.6.0.1-9rRrqEBVfs67wiLQcOHEYJ
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.14.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.14.1
id: hledger-web-1.14.1-4I0RoyFG4p72TAYL7BLtfE
key: hledger-web-1.14.1-4I0RoyFG4p72TAYL7BLtfE
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 14808252a920d5d3adcc8d57c3b58f71
exposed: True
exposed-modules:
    Hledger.Web Hledger.Web.Application Hledger.Web.Foundation
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Json Hledger.Web.Main
    Hledger.Web.Settings Hledger.Web.Settings.StaticFiles
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.14.1-4I0RoyFG4p72TAYL7BLtfE
depends:
    Decimal-0.5.1-HbE7jjGKIya5lM4gHWrRW6
    aeson-1.4.2.0-5z3HaEzpg6LIa4r5qSJGsL base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    clientsession-0.9.1.2-38NHrIsylOx2AXJejwSg9m
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-Fdyb1mU28LtFZ0fINkYHRj
    conduit-extra-1.3.1.1-L04iF81QDPdA4OkNqTJcOm containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4 directory-1.3.3.0
    filepath-1.4.2.1 hjsmin-0.2.0.2-LNLHY2IUcpaHFcPeNuDW4
    hledger-1.14.2-LF1ZV90M7xiCa3lZQo6ieQ
    hledger-lib-1.14.1-1ivD2HHtIxt9DNXh9QDvVT
    http-client-0.6.2-8bow2qd7n8PFYGg2r6fIPK
    http-conduit-2.3.7-CeUbfOmN2y47bC9EhTepzP
    http-types-0.12.3-9JOxTMGKnB3BjtQmfYBz9z
    json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    megaparsec-7.0.4-36tXbRMZL8D1XYIzLpenTI mtl-2.2.2
    shakespeare-2.0.20-G0L2S4cS9sLHCaBPgKr4K5 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    wai-3.2.2-9SAFBQJZAEOFPrdF6aQHMI
    wai-extra-3.0.25-3sAkNUwd7MaJTQh4Jqgteq
    wai-handler-launch-3.0.2.4-4Sfei2juGcI5gGGvxiDXD1
    warp-3.2.26-CKyftdQBqprEbarOuI9fM6
    yaml-0.11.0.0-GzYFOPU9U7F77K9F0swOxI
    yesod-1.6.0-DyeHTGTe3W81SH2TxzOLiV
    yesod-core-1.6.13-7LNQdxmUFoJ2TF4KGp2D5c
    yesod-form-1.6.4-CxjoYiUy81lTDCEQsC46g
    yesod-static-1.6.0.1-FrEwnt2aq9q5nMYDA1YZN2
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
